/*  SqlClassWriterTest.java
 *	Copyright (c) 2004, Brains2B.org
 *
 *	Created on: Mar 24, 2004
 *	Created by: Dennis Groenendijk
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.sql.toclass;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

import org.brains2b.sql.toclass.SqlClassWriter;
import org.brains2b.util.StringHelper;

/** Unit test for org.brains2b.sql.toclass.SqlClassWriter
 * 
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [Mar 24, 2004]
 * @see org.brains2b.sql.toclass.SqlClassWriter
 */
public class SqlClassWriterTest extends TestCase {

	private class TestSqlClassWriter extends SqlClassWriter {
		
		public TestSqlClassWriter(File location, String packageName) {
			super(location,packageName);
		}
		//abstract method do not need to test here
		protected String getClassName(String name) {
			return StringHelper.objectName(name);
		}

		// made public for test
		public File getFile(
			File location,
			String packageName,
			String className)
			throws IOException {
			
			return super.getFile(location, packageName, className);
		}

		//abstract method do not need to test here
		public File getResultfile() {
			return null;
		}

		//abstract method do not need to test here
		public void run() {
		}

		// made public for test
		public String varName(String str) {
			// TODO Auto-generated method stub
			return super.varName(str);
		}


}
	private TestSqlClassWriter classWriter;
	
	/**
	 * Constructor for SqlClassWriterTest.
	 * @param arg0
	 */
	public SqlClassWriterTest(String arg0) {
		super(arg0);
	}

	public static void main(String[] args) {
		junit.swingui.TestRunner.run(SqlClassWriterTest.class);
	}
	
	public void setUp() {
		
	}

	public void testFileExistsTrue() {
		classWriter=new TestSqlClassWriter(new File("test"),"sqlclasswriter");
		assertTrue(classWriter.fileExists("DEP_VIEW_D_C"));	
	}
	
	public void testFileExistsWrongLocation() {
		classWriter=new TestSqlClassWriter(new File(System.getProperty("java.io.tmpdir")),"sqlclasswriter");
		assertTrue(!classWriter.fileExists("DEP_VIEW"));
	}
	
	public void testFileExistsWrongVersion() {
		classWriter=new TestSqlClassWriter(new File("test"),"sqlclasswriter");
		assertTrue(!classWriter.fileExists("DEP_D_C"));
	}
	
	public void testFileExistsManuallyChanged() {
		// does exist but has manual changes
		classWriter=new TestSqlClassWriter(new File("test"),"sqlclasswriter");
		assertTrue(classWriter.fileExists("DEP"));
	}
	public void testGetFile() {
		classWriter=new TestSqlClassWriter(null,null);
		try {
			File f=classWriter.getFile(new File("test"),"sqlclasswriter","Blue");
			assertEquals("test/sqlclasswriter/Blue.java",f.getPath());
		} catch (IOException iex) {
			assertTrue(iex.getMessage(),false);
		}
		
	}

	public void testGetFileCreatePackage() {
		classWriter=new TestSqlClassWriter(null,null);
		try {
			File f=classWriter.getFile(new File(System.getProperty("java.io.tmpdir")),"sqlclasswriter","Blue");
			assertTrue(f.getParentFile().exists());
			assertEquals(System.getProperty("java.io.tmpdir")+"/sqlclasswriter/Blue.java",f.getPath());
			f.getParentFile().deleteOnExit();
		} catch (IOException iex) {
			assertTrue(iex.getMessage(),false);
		}
		
	}
	
	public void testGetFileNoPackage() {
		classWriter=new TestSqlClassWriter(null,null);
		try {
			File f=classWriter.getFile(new File("test"),null,"Blue");
			assertEquals("test/Blue.java",f.getPath());
		} catch (IOException iex) {
			assertTrue(iex.getMessage(),false);
		}
		
	}
	
	public void testGetFileNoLocation() {
		classWriter=new TestSqlClassWriter(null,null);
		try {
			File f=classWriter.getFile(null,"sqlclasswriter","Blue");
			assertEquals("Blue.java",f.getPath());	
		} catch (IOException iex) {
			assertTrue(iex.getMessage(),false);
		}
		
	}
	
	public void testVarName() {
		classWriter=new TestSqlClassWriter(null,null);
		assertEquals("x_class",classWriter.varName("Class"));
		assertEquals("x_public",classWriter.varName("Public"));
		assertEquals("parameter",classWriter.varName("Parameter"));	
	}

}
